@@ -23,7 +23,8 @@ def get_data_field(xml, field):
 def get_data(xml):
     success_xml_entry = _get_xml_field(xml, "Success")
     try:
-        data = success_xml_entry['Data']
+        data = (success_xml_entry['Data']
+                if success_xml_entry['Data'] is not None else {})
     except (KeyError, TypeError):
         data = {}
     return data
@@ -50,6 +51,6 @@ def _get_xml_field(xml, field, data_field=None):
                 msg = data[data_field]
             return msg
         except KeyError:
-            return None
+            return {}
     except xmltodict.expat.ExpatError:
         return {}
