@@ -44,8 +44,7 @@ class HttpClient(object):
     endpoint = None
 
     def __init__(self, tls_version=utils.DEFAULT_TLS_VERSION, cert=None):
-        self._tls_session = Session()
-        self._tls_session.mount("http://", UseTlsAdapter(tls_version))
+        self.tls_version = tls_version
         self.cert = cert
 
     def __enter__(self):
@@ -71,6 +70,9 @@ class HttpClient(object):
                                             cmd=rest_command)
         log.debug("Request is: %s", cmd_url)
 
+        self._tls_session = Session()
+        self._tls_session.mount("http://", UseTlsAdapter(self.tls_version))
+
         try:
             if file is not None:
                 with open(file, 'rb') as payload:
@@ -88,9 +90,10 @@ class HttpClient(object):
                                                      headers=headers,
                                                      cert=self.cert)
             if response.status_code == 401:
-                log.warning("Cannot authenticate, to %s check that the "
+                log.warning("Cannot authenticate to %s check that the "
                             "credentials are correct.", self.ip_address)
-                raise UnauthorizedAccessError(self.ip_address)
+                raise UnauthorizedAccessError(self.ip_address,
+                                              response.status_code)
             elif 400 < response.status_code < 500:
                 raise KempTechApiException(msg=response.text,
                                            code=response.status_code)
@@ -365,7 +368,14 @@ class LoadMaster(HttpClient):
                                                            ip=self.ip_address,
                                                            port=self.port)
         try:
-            self._tls_session.get(url, verify=False, timeout=1)
+            self._tls_session = Session()
+            self._tls_session.mount("http://", UseTlsAdapter(self.tls_version))
+            if self.cert:
+                self._tls_session.get(url, verify=False, timeout=1,
+                                      cert=self.cert)
+            else:
+                self._tls_session.get(url, verify=False, timeout=1,
+                                      cert=self.cert)
             return True
         except exceptions.RequestException:
             return False
